/*
 * test of options.h
 */
#include <stdio.h>
#include <string.h>
#include <options.h>

enum {
  BLACK,
  BLUE,
  GREEN,
  CYAN,
  RED,
  MAGENTA,
  BROWN,
  LIGHTGRAY,
  DARKGRAY,
  LIGHTBLUE,
  LIGHTGREEN,
  LIGHTCYAN,
  LIGHTRED,
  LIGHTMAGENTA,
  YELLOW,
  WHITE
};
char *color[] = {
  "BLACK",
  "BLUE",
  "GREEN",
  "CYAN",
  "RED",
  "MAGENTA",
  "BROWN",
  "LIGHTGRAY",
  "DARKGRAY",
  "LIGHTBLUE",
  "LIGHTGREEN",
  "LIGHTCYAN",
  "LIGHTRED",
  "LIGHTMAGENTA",
  "YELLOW",
  "WHITE",
};
char buf[256];

/*
 * global variables for example
 */
char title[256] = "test program of options.h";
char name[256] = "options0";
char c = 'c';
int flag = !0;
int number = 0;
int width = 500, height = 400;
float f = 0.001;
double d = 0.002;

/*
 * packed technique of options
 */
option_record options[] = {
  { "-t %s",     title },
  { "-n \"%s\"", name  },
  { "-c %c",     &c    },
  { "-on[-]",    &flag },
  { "-f %f",     &f    },
  { "-d %lf",    &d    },
  { "-help",     NULL  }
};

/*
 * to show variables for example
 */
void usage( FILE *fp )
{
  fprintf( fp, "options ... \n" );
  fprintf( fp, "\t-t name:    to set string (%s).   \n", title );
  fprintf( fp, "\t-n name:    to set string (%s).   \n", name );
  fprintf( fp, "\t-c char:    to set character (%c).\n", c );
  fprintf( fp, "\t-on[-]:     to set flag (%s).     \n", flag?"ON":"OFF" );
  fprintf( fp, "\t-color enum to set enumerate (%s) \n", color[number] );
  fprintf( fp, "\t-geom WxH:  to set ints (%1dx%1d).\n", width, height );
  fprintf( fp, "\t-f float:   to set float (%f).    \n", f );
  fprintf( fp, "\t-d double:  to set double (%f).   \n", d );
  fprintf( fp, "\t-help:      show this help.       \n" );
}

void main( int argc, char *argv[] )
{
  int i;
  /*
   * entry options
   */
  set_options( 7, options );
  set_option( "-geom %dx%d", &width, &height );
  strcpy( buf, "-color " );
  for ( i=0; i<16; i++ ){
    strcat( buf, color[i] );
    strcat( buf, " " );
  }
  set_option( buf, &number );
  alias_option( "-geom", "-geometry" );
  /*
   * procedures for an example
   */
  printf( "*** DEFAULT SETTINGS ***\n" );
  usage( stdout );
  /*
   * print command line
   */
  printf( "*** COMMAND LINE ***\n" );
  for ( i=0; i<argc; i++ )
    printf( "\"%s\"", argv[i] );
  printf( "\n" );
  /*
   * analyze options and get results
   */
  scan_options( argc, argv );
  if ( is_option( "-help" ) ){
    printf( "*** SETTINGS BY YOUR OPTIONS ***\n" );
    usage( stdout );
    fprintf( stdout, "There is help option.\n" );
    exit( 0 );
  }
  /*
   * procedures for an example
   */
  printf( "*** SETTINGS BY YOUR OPTIONS ***\n" );
  usage( stdout );
  /*
   * closing options routines
   */
  reset_options();

  exit( 0 );
}
